@@ -605,7 +605,7 @@ class AutoScaleConfig(BaseModel):
 
     @root_validator()
     def check_data(cls, values: Any) -> Any:
-        if values["min_size"] <= values["max_size"]:
+        if values["min_size"] > values["max_size"]:
             raise ValueError("The pool min_size is greater than max_size")
         return values
 
@@ -794,6 +794,59 @@ class Task(BaseModel):
     user_info: Optional[UserInfo]
 
 
+class NetworkConfig(BaseModel):
+    address_space: str = Field(default="10.0.0.0/8")
+    subnet: str = Field(default="10.0.0.0/16")
+
+
+class NetworkSecurityGroupConfig(BaseModel):
+    allowed_service_tags: List[str] = Field(default_factory=list)
+    allowed_ips: List[str] = Field(default_factory=list)
+
+
+class KeyvaultExtensionConfig(BaseModel):
+    keyvault_name: str
+    cert_name: str
+    cert_path: str
+    extension_store: str
+
+
+class AzureMonitorExtensionConfig(BaseModel):
+    config_version: str
+    moniker: str
+    namespace: str
+    monitoringGSEnvironment: str
+    monitoringGCSAccount: str
+    monitoringGCSAuthId: str
+    monitoringGCSAuthIdType: str
+
+
+class AzureSecurityExtensionConfig(BaseModel):
+    pass
+
+
+class GenevaExtensionConfig(BaseModel):
+    pass
+
+
+class AzureVmExtensionConfig(BaseModel):
+    keyvault: Optional[KeyvaultExtensionConfig]
+    azure_monitor: Optional[AzureMonitorExtensionConfig]
+    azure_security: Optional[AzureSecurityExtensionConfig]
+    geneva: Optional[GenevaExtensionConfig]
+
+
+class ApiAccessRule(BaseModel):
+    methods: List[str]
+    allowed_groups: List[UUID]
+
+
+Endpoint = str
+# json dumps doesn't support UUID as dictionary key
+PrincipalID = str
+GroupId = UUID
+
+
 class InstanceConfig(BaseModel):
     # initial set of admins can only be set during deployment.
     # if admins are set, only admins can update instance configs.
@@ -802,6 +855,16 @@ class InstanceConfig(BaseModel):
     # if set, only admins can manage pools or scalesets
     allow_pool_management: bool = Field(default=True)
 
+    allowed_aad_tenants: List[UUID]
+    network_config: NetworkConfig = Field(default_factory=NetworkConfig)
+    proxy_nsg_config: NetworkSecurityGroupConfig = Field(
+        default_factory=NetworkSecurityGroupConfig
+    )
+    extensions: Optional[AzureVmExtensionConfig]
+    proxy_vm_sku: str = Field(default="Standard_B2s")
+    api_access_rules: Optional[Dict[Endpoint, ApiAccessRule]] = None
+    group_membership: Optional[Dict[PrincipalID, List[GroupId]]] = None
+
     def update(self, config: "InstanceConfig") -> None:
         for field in config.__fields__:
             # If no admins are set, then ignore setting admins
@@ -817,5 +880,16 @@ class InstanceConfig(BaseModel):
             raise ValueError("admins must be None or contain at least one UUID")
         return value
 
+    # At the moment, this only checks allowed_aad_tenants, however adding
+    # support for 3rd party JWT validation is anticipated in a future release.
+    @root_validator()
+    def check_instance_config(cls, values: Any) -> Any:
+        if "allowed_aad_tenants" not in values:
+            raise ValueError("missing allowed_aad_tenants")
+
+        if not len(values["allowed_aad_tenants"]):
+            raise ValueError("allowed_aad_tenants must not be empty")
+        return values
+
 
 _check_hotfix()
